@@ -24,15 +24,21 @@ __all__ = (
     "ArtworkTypeDef",
     "AudioCodecOptionsTypeDef",
     "AudioParametersTypeDef",
+    "CancelJobRequestTypeDef",
     "CaptionFormatTypeDef",
     "CaptionSourceTypeDef",
     "CaptionsTypeDef",
     "ClipTypeDef",
     "CreateJobOutputTypeDef",
     "CreateJobPlaylistTypeDef",
-    "CreateJobResponseTypeDef",
-    "CreatePipelineResponseTypeDef",
-    "CreatePresetResponseTypeDef",
+    "CreateJobRequestTypeDef",
+    "CreateJobResponseResponseTypeDef",
+    "CreatePipelineRequestTypeDef",
+    "CreatePipelineResponseResponseTypeDef",
+    "CreatePresetRequestTypeDef",
+    "CreatePresetResponseResponseTypeDef",
+    "DeletePipelineRequestTypeDef",
+    "DeletePresetRequestTypeDef",
     "DetectedPropertiesTypeDef",
     "EncryptionTypeDef",
     "HlsContentProtectionTypeDef",
@@ -42,10 +48,14 @@ __all__ = (
     "JobOutputTypeDef",
     "JobTypeDef",
     "JobWatermarkTypeDef",
-    "ListJobsByPipelineResponseTypeDef",
-    "ListJobsByStatusResponseTypeDef",
-    "ListPipelinesResponseTypeDef",
-    "ListPresetsResponseTypeDef",
+    "ListJobsByPipelineRequestTypeDef",
+    "ListJobsByPipelineResponseResponseTypeDef",
+    "ListJobsByStatusRequestTypeDef",
+    "ListJobsByStatusResponseResponseTypeDef",
+    "ListPipelinesRequestTypeDef",
+    "ListPipelinesResponseResponseTypeDef",
+    "ListPresetsRequestTypeDef",
+    "ListPresetsResponseResponseTypeDef",
     "NotificationsTypeDef",
     "PaginatorConfigTypeDef",
     "PermissionTypeDef",
@@ -55,17 +65,24 @@ __all__ = (
     "PlaylistTypeDef",
     "PresetTypeDef",
     "PresetWatermarkTypeDef",
-    "ReadJobResponseTypeDef",
-    "ReadPipelineResponseTypeDef",
-    "ReadPresetResponseTypeDef",
+    "ReadJobRequestTypeDef",
+    "ReadJobResponseResponseTypeDef",
+    "ReadPipelineRequestTypeDef",
+    "ReadPipelineResponseResponseTypeDef",
+    "ReadPresetRequestTypeDef",
+    "ReadPresetResponseResponseTypeDef",
     "ResponseMetadataTypeDef",
-    "TestRoleResponseTypeDef",
+    "TestRoleRequestTypeDef",
+    "TestRoleResponseResponseTypeDef",
     "ThumbnailsTypeDef",
     "TimeSpanTypeDef",
     "TimingTypeDef",
-    "UpdatePipelineNotificationsResponseTypeDef",
-    "UpdatePipelineResponseTypeDef",
-    "UpdatePipelineStatusResponseTypeDef",
+    "UpdatePipelineNotificationsRequestTypeDef",
+    "UpdatePipelineNotificationsResponseResponseTypeDef",
+    "UpdatePipelineRequestTypeDef",
+    "UpdatePipelineResponseResponseTypeDef",
+    "UpdatePipelineStatusRequestTypeDef",
+    "UpdatePipelineStatusResponseResponseTypeDef",
     "VideoParametersTypeDef",
     "WaiterConfigTypeDef",
     "WarningTypeDef",
@@ -109,6 +126,13 @@ AudioParametersTypeDef = TypedDict(
     total=False,
 )
 
+CancelJobRequestTypeDef = TypedDict(
+    "CancelJobRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
 CaptionFormatTypeDef = TypedDict(
     "CaptionFormatTypeDef",
     {
@@ -163,8 +187,8 @@ CreateJobOutputTypeDef = TypedDict(
         "Composition": List["ClipTypeDef"],
         "Captions": "CaptionsTypeDef",
         "Encryption": "EncryptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
+    total=False,
 )
 
 CreateJobPlaylistTypeDef = TypedDict(
@@ -179,30 +203,121 @@ CreateJobPlaylistTypeDef = TypedDict(
     total=False,
 )
 
-CreateJobResponseTypeDef = TypedDict(
-    "CreateJobResponseTypeDef",
+_RequiredCreateJobRequestTypeDef = TypedDict(
+    "_RequiredCreateJobRequestTypeDef",
     {
-        "Job": "JobTypeDef",
+        "PipelineId": str,
+    },
+)
+_OptionalCreateJobRequestTypeDef = TypedDict(
+    "_OptionalCreateJobRequestTypeDef",
+    {
+        "Input": "JobInputTypeDef",
+        "Inputs": List["JobInputTypeDef"],
+        "Output": "CreateJobOutputTypeDef",
+        "Outputs": List["CreateJobOutputTypeDef"],
+        "OutputKeyPrefix": str,
+        "Playlists": List["CreateJobPlaylistTypeDef"],
+        "UserMetadata": Dict[str, str],
     },
     total=False,
 )
 
-CreatePipelineResponseTypeDef = TypedDict(
-    "CreatePipelineResponseTypeDef",
+
+class CreateJobRequestTypeDef(_RequiredCreateJobRequestTypeDef, _OptionalCreateJobRequestTypeDef):
+    pass
+
+
+CreateJobResponseResponseTypeDef = TypedDict(
+    "CreateJobResponseResponseTypeDef",
+    {
+        "Job": "JobTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreatePipelineRequestTypeDef = TypedDict(
+    "_RequiredCreatePipelineRequestTypeDef",
+    {
+        "Name": str,
+        "InputBucket": str,
+        "Role": str,
+    },
+)
+_OptionalCreatePipelineRequestTypeDef = TypedDict(
+    "_OptionalCreatePipelineRequestTypeDef",
+    {
+        "OutputBucket": str,
+        "AwsKmsKeyArn": str,
+        "Notifications": "NotificationsTypeDef",
+        "ContentConfig": "PipelineOutputConfigTypeDef",
+        "ThumbnailConfig": "PipelineOutputConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class CreatePipelineRequestTypeDef(
+    _RequiredCreatePipelineRequestTypeDef, _OptionalCreatePipelineRequestTypeDef
+):
+    pass
+
+
+CreatePipelineResponseResponseTypeDef = TypedDict(
+    "CreatePipelineResponseResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
         "Warnings": List["WarningTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreatePresetRequestTypeDef = TypedDict(
+    "_RequiredCreatePresetRequestTypeDef",
+    {
+        "Name": str,
+        "Container": str,
+    },
+)
+_OptionalCreatePresetRequestTypeDef = TypedDict(
+    "_OptionalCreatePresetRequestTypeDef",
+    {
+        "Description": str,
+        "Video": "VideoParametersTypeDef",
+        "Audio": "AudioParametersTypeDef",
+        "Thumbnails": "ThumbnailsTypeDef",
     },
     total=False,
 )
 
-CreatePresetResponseTypeDef = TypedDict(
-    "CreatePresetResponseTypeDef",
+
+class CreatePresetRequestTypeDef(
+    _RequiredCreatePresetRequestTypeDef, _OptionalCreatePresetRequestTypeDef
+):
+    pass
+
+
+CreatePresetResponseResponseTypeDef = TypedDict(
+    "CreatePresetResponseResponseTypeDef",
     {
         "Preset": "PresetTypeDef",
         "Warning": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeletePipelineRequestTypeDef = TypedDict(
+    "DeletePipelineRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+DeletePresetRequestTypeDef = TypedDict(
+    "DeletePresetRequestTypeDef",
+    {
+        "Id": str,
     },
-    total=False,
 )
 
 DetectedPropertiesTypeDef = TypedDict(
@@ -300,8 +415,8 @@ JobOutputTypeDef = TypedDict(
         "Captions": "CaptionsTypeDef",
         "Encryption": "EncryptionTypeDef",
         "AppliedColorSpaceConversion": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
+    total=False,
 )
 
 JobTypeDef = TypedDict(
@@ -333,40 +448,102 @@ JobWatermarkTypeDef = TypedDict(
     total=False,
 )
 
-ListJobsByPipelineResponseTypeDef = TypedDict(
-    "ListJobsByPipelineResponseTypeDef",
+_RequiredListJobsByPipelineRequestTypeDef = TypedDict(
+    "_RequiredListJobsByPipelineRequestTypeDef",
     {
-        "Jobs": List["JobTypeDef"],
-        "NextPageToken": str,
+        "PipelineId": str,
+    },
+)
+_OptionalListJobsByPipelineRequestTypeDef = TypedDict(
+    "_OptionalListJobsByPipelineRequestTypeDef",
+    {
+        "Ascending": str,
+        "PageToken": str,
     },
     total=False,
 )
 
-ListJobsByStatusResponseTypeDef = TypedDict(
-    "ListJobsByStatusResponseTypeDef",
+
+class ListJobsByPipelineRequestTypeDef(
+    _RequiredListJobsByPipelineRequestTypeDef, _OptionalListJobsByPipelineRequestTypeDef
+):
+    pass
+
+
+ListJobsByPipelineResponseResponseTypeDef = TypedDict(
+    "ListJobsByPipelineResponseResponseTypeDef",
     {
         "Jobs": List["JobTypeDef"],
         "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListJobsByStatusRequestTypeDef = TypedDict(
+    "_RequiredListJobsByStatusRequestTypeDef",
+    {
+        "Status": str,
+    },
+)
+_OptionalListJobsByStatusRequestTypeDef = TypedDict(
+    "_OptionalListJobsByStatusRequestTypeDef",
+    {
+        "Ascending": str,
+        "PageToken": str,
     },
     total=False,
 )
 
-ListPipelinesResponseTypeDef = TypedDict(
-    "ListPipelinesResponseTypeDef",
+
+class ListJobsByStatusRequestTypeDef(
+    _RequiredListJobsByStatusRequestTypeDef, _OptionalListJobsByStatusRequestTypeDef
+):
+    pass
+
+
+ListJobsByStatusResponseResponseTypeDef = TypedDict(
+    "ListJobsByStatusResponseResponseTypeDef",
+    {
+        "Jobs": List["JobTypeDef"],
+        "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListPipelinesRequestTypeDef = TypedDict(
+    "ListPipelinesRequestTypeDef",
+    {
+        "Ascending": str,
+        "PageToken": str,
+    },
+    total=False,
+)
+
+ListPipelinesResponseResponseTypeDef = TypedDict(
+    "ListPipelinesResponseResponseTypeDef",
     {
         "Pipelines": List["PipelineTypeDef"],
         "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListPresetsRequestTypeDef = TypedDict(
+    "ListPresetsRequestTypeDef",
+    {
+        "Ascending": str,
+        "PageToken": str,
     },
     total=False,
 )
 
-ListPresetsResponseTypeDef = TypedDict(
-    "ListPresetsResponseTypeDef",
+ListPresetsResponseResponseTypeDef = TypedDict(
+    "ListPresetsResponseResponseTypeDef",
     {
         "Presets": List["PresetTypeDef"],
         "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 NotificationsTypeDef = TypedDict(
@@ -488,29 +665,50 @@ PresetWatermarkTypeDef = TypedDict(
     total=False,
 )
 
-ReadJobResponseTypeDef = TypedDict(
-    "ReadJobResponseTypeDef",
+ReadJobRequestTypeDef = TypedDict(
+    "ReadJobRequestTypeDef",
     {
-        "Job": "JobTypeDef",
+        "Id": str,
     },
-    total=False,
 )
 
-ReadPipelineResponseTypeDef = TypedDict(
-    "ReadPipelineResponseTypeDef",
+ReadJobResponseResponseTypeDef = TypedDict(
+    "ReadJobResponseResponseTypeDef",
+    {
+        "Job": "JobTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ReadPipelineRequestTypeDef = TypedDict(
+    "ReadPipelineRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+ReadPipelineResponseResponseTypeDef = TypedDict(
+    "ReadPipelineResponseResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
         "Warnings": List["WarningTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-ReadPresetResponseTypeDef = TypedDict(
-    "ReadPresetResponseTypeDef",
+ReadPresetRequestTypeDef = TypedDict(
+    "ReadPresetRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+ReadPresetResponseResponseTypeDef = TypedDict(
+    "ReadPresetResponseResponseTypeDef",
     {
         "Preset": "PresetTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -524,13 +722,23 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-TestRoleResponseTypeDef = TypedDict(
-    "TestRoleResponseTypeDef",
+TestRoleRequestTypeDef = TypedDict(
+    "TestRoleRequestTypeDef",
+    {
+        "Role": str,
+        "InputBucket": str,
+        "OutputBucket": str,
+        "Topics": List[str],
+    },
+)
+
+TestRoleResponseResponseTypeDef = TypedDict(
+    "TestRoleResponseResponseTypeDef",
     {
         "Success": str,
         "Messages": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ThumbnailsTypeDef = TypedDict(
@@ -567,29 +775,72 @@ TimingTypeDef = TypedDict(
     total=False,
 )
 
-UpdatePipelineNotificationsResponseTypeDef = TypedDict(
-    "UpdatePipelineNotificationsResponseTypeDef",
+UpdatePipelineNotificationsRequestTypeDef = TypedDict(
+    "UpdatePipelineNotificationsRequestTypeDef",
+    {
+        "Id": str,
+        "Notifications": "NotificationsTypeDef",
+    },
+)
+
+UpdatePipelineNotificationsResponseResponseTypeDef = TypedDict(
+    "UpdatePipelineNotificationsResponseResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdatePipelineRequestTypeDef = TypedDict(
+    "_RequiredUpdatePipelineRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalUpdatePipelineRequestTypeDef = TypedDict(
+    "_OptionalUpdatePipelineRequestTypeDef",
+    {
+        "Name": str,
+        "InputBucket": str,
+        "Role": str,
+        "AwsKmsKeyArn": str,
+        "Notifications": "NotificationsTypeDef",
+        "ContentConfig": "PipelineOutputConfigTypeDef",
+        "ThumbnailConfig": "PipelineOutputConfigTypeDef",
     },
     total=False,
 )
 
-UpdatePipelineResponseTypeDef = TypedDict(
-    "UpdatePipelineResponseTypeDef",
+
+class UpdatePipelineRequestTypeDef(
+    _RequiredUpdatePipelineRequestTypeDef, _OptionalUpdatePipelineRequestTypeDef
+):
+    pass
+
+
+UpdatePipelineResponseResponseTypeDef = TypedDict(
+    "UpdatePipelineResponseResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
         "Warnings": List["WarningTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-UpdatePipelineStatusResponseTypeDef = TypedDict(
-    "UpdatePipelineStatusResponseTypeDef",
+UpdatePipelineStatusRequestTypeDef = TypedDict(
+    "UpdatePipelineStatusRequestTypeDef",
+    {
+        "Id": str,
+        "Status": str,
+    },
+)
+
+UpdatePipelineStatusResponseResponseTypeDef = TypedDict(
+    "UpdatePipelineStatusResponseResponseTypeDef",
     {
         "Pipeline": "PipelineTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 VideoParametersTypeDef = TypedDict(
